const Ipc = require('electron-ipc-renderer-extend');

const EVENT = {
    ON_OPEN_EXTERNAL_LINK: 'on-open-external-link',
    ON_MINIMIZE: 'on-minimize',
    ON_CLOSE: 'on-close',
    ON_GOTO_PAGE: 'on-goto-page',
    ON_GET_TITLE_BAR: 'on-get-title-bar',
    ON_GET_APPLICATION_VERSION: 'on-get-application-version',
    ON_OPEN_FILE_DIALOG: 'on-open-file-dialog',
}


function onMinimizeClick() {
    Ipc.once(EVENT.ON_MINIMIZE);
}

function onCloseClick() {
    Ipc.once(EVENT.ON_CLOSE);
}

function onExternalLinkClicked(event) {
    Ipc.once(EVENT.ON_OPEN_EXTERNAL_LINK, $(this).attr('href'));
    event.preventDefault();
}

function initialize(appName, appIcon, backTargetPage, isNeedConfirm, message) {


    // Add css for global partial
    $(`<link href='${__dirname}/style.css' rel='stylesheet'>`).insertBefore($('link').last());


    // Get and render globak view
    Ipc.once(EVENT.ON_GET_TITLE_BAR, null, EVENT.ON_GET_TITLE_BAR)
        .then((result) => {
            $('body').prepend(result.data);
            $('#window-minimize').on('click', onMinimizeClick);
            $('#window-close').on('click', onCloseClick);

            if (appName !== null && appName !== undefined && appName !== '') {
                $('#app-name').html(appName);
            }

            if (appIcon !== null && appIcon !== undefined && appIcon !== '') {
                $('#app-icon').attr('src', appIcon);
            }

            if (backTargetPage !== null && backTargetPage !== undefined) {
                $('#backButton').removeAttr('style');
                //$('#title-bar-dragable').attr('style','margin-left: 54px');
                $('#backButton').on('click', function() {
                    if (isNeedConfirm) {
                        confirm('', message == undefined ? 'Do you really want to back previous page' : message, function() {
                            Ipc.once(EVENT.ON_GOTO_PAGE, backTargetPage);
                        });
                    } else {
                        Ipc.once(EVENT.ON_GOTO_PAGE, backTargetPage);
                    }
                });
            }
        })
        .catch((e) => {
            alert('', e);
        })

    // Blind and process event click to external link
    $(document).on('click', 'a[target="_blank"]', onExternalLinkClicked);

}

function alert(title, message, onCloseCallback) {
    $('#alertModalTitle').html(title);
    $('#alertModalMessage').html(message);
    $('#alertModal').on('hidden.bs.modal', onCloseCallback);
    $('#alertModalClose').on('click', function() {
        $('#alertModal').modal('hide');
    });
    $('#alertModal').modal('show');
}

function confirm(title, message, onSubmit, onCancel, OKLabel = 'OK') {
    $('confirmModalOK').text(OKLabel);
    $('#confirmModal').modal({ backdrop: 'static', keyboard: false });
    $('#confirmModalTitle').html(title);
    $('#confirmModalMessage').html(message);
    $('#confirmModalCancel').on('click', function(event) {
        $('#confirmModal').modal('hide');
        if (onCancel !== undefined && onCancel !== null) {
            onCancel(event);
        }
    });
    $('#confirmModalOK').on('click', function() {
        $('#confirmModal').modal('hide');
        onSubmit();
    });
    $('#confirmModal').modal('show');
}


module.exports.initialize = initialize;
module.exports.alert = alert;
module.exports.confirm = confirm;